You are viewing a plain text version of this content. The canonical link for it is here.
Posted to cvs@httpd.apache.org by ni...@apache.org on 2009/09/15 18:10:22 UTC

svn commit: r815380 - in /httpd/httpd/trunk: CHANGES docs/manual/mod/mod_dir.xml modules/mappers/mod_dir.c

Author: niq
Date: Tue Sep 15 16:10:21 2009
New Revision: 815380

URL: http://svn.apache.org/viewvc?rev=815380&view=rev
Log:
Change "DefaultHandler" to "Fallback" as discussed on list and
today on IRC, in the hope that everyone will be satisfied.
PR: 47184 + subsequent veto of original directive name

Modified:
    httpd/httpd/trunk/CHANGES
    httpd/httpd/trunk/docs/manual/mod/mod_dir.xml
    httpd/httpd/trunk/modules/mappers/mod_dir.c

Modified: httpd/httpd/trunk/CHANGES
URL: http://svn.apache.org/viewvc/httpd/httpd/trunk/CHANGES?rev=815380&r1=815379&r2=815380&view=diff
==============================================================================
--- httpd/httpd/trunk/CHANGES [utf-8] (original)
+++ httpd/httpd/trunk/CHANGES [utf-8] Tue Sep 15 16:10:21 2009
@@ -105,7 +105,7 @@
   *) mod_alias: ensure Redirect issues a valid URL.
      PR 44020 [HÃ¥kon Stordahl <hakon stordahl.org>]
 
-  *) mod_dir: add DefaultHandler directive, to enable admin to specify
+  *) mod_dir: add Fallback directive, to enable admin to specify
      an action to happen when a URL maps to no file, without resorting
      to ErrorDocument or mod_rewrite.  PR 47184 [Nick Kew]
 

Modified: httpd/httpd/trunk/docs/manual/mod/mod_dir.xml
URL: http://svn.apache.org/viewvc/httpd/httpd/trunk/docs/manual/mod/mod_dir.xml?rev=815380&r1=815379&r2=815380&view=diff
==============================================================================
--- httpd/httpd/trunk/docs/manual/mod/mod_dir.xml (original)
+++ httpd/httpd/trunk/docs/manual/mod/mod_dir.xml Tue Sep 15 16:10:21 2009
@@ -157,9 +157,9 @@
 </usage>
 </directivesynopsis>
 <directivesynopsis>
-<name>DefaultMapping</name>
+<name>Fallback</name>
 <description>Define a default URL for requests that don't map to a file</description>
-<syntax>DefaultMapping <var>local-url</var></syntax>
+<syntax>Fallback <var>local-url</var></syntax>
 <default>None - httpd will return 404 (Not Found)</default>
 <contextlist><context>server config</context><context>virtual host</context>
 <context>directory</context><context>.htaccess</context></contextlist>
@@ -169,10 +169,10 @@
     in your filesystem, and would otherwise return HTTP 404 (Not Found).
     For example</p>
     <example>
-        <code>DefaultMapping default.php</code>
+        <code>Fallback not-404.php</code>
     </example>
     <p>will cause requests for non-existent files to be handled by
-    <code>default.php</code>, while requests for files that exist
+    <code>not-404.php</code>, while requests for files that exist
     are unaffected.</p>
 </usage>
 </directivesynopsis>

Modified: httpd/httpd/trunk/modules/mappers/mod_dir.c
URL: http://svn.apache.org/viewvc/httpd/httpd/trunk/modules/mappers/mod_dir.c?rev=815380&r1=815379&r2=815380&view=diff
==============================================================================
--- httpd/httpd/trunk/modules/mappers/mod_dir.c (original)
+++ httpd/httpd/trunk/modules/mappers/mod_dir.c Tue Sep 15 16:10:21 2009
@@ -83,7 +83,7 @@
 
 static const command_rec dir_cmds[] =
 {
-    AP_INIT_TAKE1("DefaultMapping", ap_set_string_slot,
+    AP_INIT_TAKE1("Fallback", ap_set_string_slot,
                   (void*)APR_OFFSETOF(dir_config_rec, dflt),
                   DIR_CMD_PERMS, "Set a default handler"),
     AP_INIT_RAW_ARGS("DirectoryIndex", add_index, NULL, DIR_CMD_PERMS,
@@ -128,7 +128,7 @@
     if (name_ptr == NULL) {
         return DECLINED;
     }
     /* XXX: if DefaultHandler points to something that doesn't exist,
      * this may recurse until it hits the limit for internal redirects
      * before returning an Internal Server Error.
      */
@@ -128,7 +128,7 @@
         return DECLINED;
     }
-    /* XXX: if DefaultHandler points to something that doesn't exist,
+    /* XXX: if Fallback points to something that doesn't exist,
      * this may recurse until it hits the limit for internal redirects
      * before returning an Internal Server Error.